@@ -198,7 +198,19 @@ class IotToS3(
         :summary: Constructs a new instance of the IotToSqs class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IotToS3.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                s3_key: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToS3Props(
@@ -278,7 +290,17 @@ class IotToS3Props:
         if isinstance(logging_bucket_props, dict):
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if __debug__:
-            type_hints = typing.get_type_hints(IotToS3Props.__init__)
+            def stub(
+                *,
+                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                s3_key: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument existing_bucket_interface", value=existing_bucket_interface, expected_type=type_hints["existing_bucket_interface"])
